diff lisp/progmodes/fortran.el @ 3591:507f64624555

Apply typo patches from Paul Eggert.
author Jim Blandy <jimb@redhat.com>
date Wed, 09 Jun 1993 11:59:12 +0000
parents 2ca5f216e445
children cd3d59bc0b94
line wrap: on
line diff
--- a/lisp/progmodes/fortran.el	Wed Jun 09 11:33:38 1993 +0000
+++ b/lisp/progmodes/fortran.el	Wed Jun 09 11:59:12 1993 +0000
@@ -27,7 +27,7 @@
 
 ;; Fortran mode has been upgraded and is now maintained by Stephen A. Wood
 ;; (saw@cebaf.gov).  It now will use either fixed format continuation line
-;; markers (character in 6th column), or tab format coninuation line style
+;; markers (character in 6th column), or tab format continuation line style
 ;; (digit after a TAB character.)  A auto-fill mode has been added to
 ;; automatically wrap fortran lines that get too long.
 
@@ -37,7 +37,7 @@
 ;; Gary Sabot and Richard Stallman.
 
 ;;; This file may be used with GNU Emacs version 18.xx if the following
-;;; variable and function substutions are made.
+;;; variable and function substitutions are made.
 ;;;  Replace:
 ;;;   frame-width                           with screen-width
 ;;;   auto-fill-function                    with auto-fill-hook
@@ -159,7 +159,7 @@
  style.")
 
 (defvar fortran-break-before-delimiters t
-  "*Non-nil causes `fortran-do-auto-fill' to break lines before delimeters.")
+  "*Non-nil causes `fortran-do-auto-fill' to break lines before delimiters.")
 
 (if fortran-mode-syntax-table
     ()
@@ -336,7 +336,7 @@
     Non-nil causes line number digits to be moved to the correct column 
     as typed.  (default t)
  fortran-break-before-delimiters
-    Non-nil causes `fortran-do-auto-fill' breaks lines before delimeters.
+    Non-nil causes `fortran-do-auto-fill' breaks lines before delimiters.
     (default t)
  fortran-startup-message
     Set to nil to inhibit message first time Fortran mode is used.
@@ -1117,7 +1117,7 @@
 	 ;; decide where to split the line. If a position for a quoted
 	 ;; string was found above then use that, else break the line
 	 ;; before the last delimiter.
 	 ;; Delimeters are whitespace, commas, and operators.
 	 ;; Will break before a pair of *'s.
 	 ;;
 	 (fill-point
@@ -1117,7 +1117,7 @@
 	 ;; string was found above then use that, else break the line
 	 ;; before the last delimiter.
-	 ;; Delimeters are whitespace, commas, and operators.
+	 ;; Delimiters are whitespace, commas, and operators.
 	 ;; Will break before a pair of *'s.
 	 ;;